;================================================================================
;
;NXP 26C92 DUAL UART (DUART) REGISTER DEFINITIONS
;
n_schans =2                    ;number of serial channels
s_c92blk =8                    ;channel register base spacing
c92_chax =0                    ;channel A cardinal index
c92_chbx =1                    ;channel B cardinal index
c92_cha  =s_c92blk*c92_chax    ;channel A register base
c92_chb  =s_c92blk*c92_chbx    ;channel B register base
;
;
;	
;	Per-Channel Register Definitions
;	
;
c92_mr   =0                    ;mode select (R/W)...
;
;	xxxx0xxx > mode 0 (MR0) settings...
;	|||| |||
;	|||| +++> baud rate extend:  000: normal
;	||||                            001: extended mode 1
;	||||                            100: extended mode 2
;	||++> TxD FIFO IRQ level: 00: 8
;	||                               01: 4
;	||                               10: 6
;	||                               11: 1
;	|+> RxD FIFO IRQ level:  0: 1-5: see also MR1:6
;	|                                 1: 6-8: see also MR1:6
;	+> RxD watchdog:        0: disable
;	                                  1: enable
;
;	xxxxxxxx > mode 1 (MR1) settings...
;	||||||||
;	||||||++> data format:  00: 5 bit
;	||||||                     01: 6 bit
;	||||||                     10: 7 bit
;	||||||                     11: 8 bit
;	|||||+> parity type:   0: even
;	|||||                       1: odd
;	|||++> parity mode:  00: check
;	|||                        01: force
;	|||                        10: don't check
;	|||                        11: multidrop
;	||+> error mode:    0: character
;	||                          1: block
;	|+> RxD IRQ mode:  0: RxD ready
;	|                           1: FIFO full
;	+> RxD RTS mode:  0: off
;	                            1: on
;
;	xxxxxxxx > mode 2 (MR2) settings...
;	||||||||
;	||||++++> stop bit length
;	||||
;	|||+> TxD CTS mode:        0: off
;	|||                               1: on
;	||+> TxD RTS mode:        0: off
;	||                                1: on
;	++> channel mode:       00: normal
;	                                 01: auto echo 
;	                                 10: local loop
;	                                 11: remote loop
;
c92_sr   =1                    ;status (R)...
;
;	xxxxxxxx
;	||||||||
;	|||||||+> 1: RxD FIFO not empty
;	||||||+> 1: RxD FIFO full
;	|||||+> 1: TxD FIFO not empty
;	||||+> 1: TxD FIFO empty
;	|||+> 1: RxD overrun
;	||+> 1: parity error
;	|+> 1: framing error
;	+> 1: break received
;
c92_csr  =1                    ;clock select (W)...
;
;	xxxxxxxx
;	||||||||
;	||||++++> TxD baud rate & BRG source
;	++++> RxD baud rate & BRG source
;
c92_cr   =2                    ;command (W)...
;
;	xxxxxxxx
;	||||||||
;	||||||++>   00: no operation
;	||||||         01: enable receiver
;	||||||         10: disable receiver
;	||||||         11: undefined
;	||||++>   00: no operation
;	||||           01: enable transmitter
;	||||           10: disable transmitter
;	||||           11: undefined
;	++++> 0000: no operation
;	             0001: select MR1
;	             0010: reset & disable receiver
;	             0011: reset & disable transmitter
;	             0100: reset error status
;	             0101: reset break IRQ
;	             0110: start TxD break
;	             0111: stop TxD break
;	             1000: assert RTS
;	             1001: deassert RTS
;	             1010: enable C/T timeout mode
;	             1011: select MR0
;	             1100: disable C/T timeout mode
;	             1101: undefined
;	             1110: standby power mode*
;	             1111: normal power mode*
;
;	* channel A only, otherwise undefined
;
c92_rhr  =3                    ;RxD FIFO (R)
c92_thr  =3                    ;TxD FIFO (W)
;
;
;	
;	Device Control Register Definitions
;	
;
dr_ipcr  =4                    ;input port change (R)
dr_acr   =4                    ;auxiliary control (W)...
;
;	xxxxxxxx
;	||||||||
;	|||||||+> 1: enable IP0 IRQ
;	||||||+> 1: enable IP1 IRQ
;	|||||+> 1: enable IP2 IRQ
;	||||+> 1: enable IP3 IRQ
;	|+++> C/T setup:
;	|
;	|            654  Mode     Source
;	|            
;	|            000  counter  IP2
;	|            001  counter  TxD Ch 1 1X clock
;	|            010  counter  TxD Ch 2 1X clock
;	|            011  counter  X1 clock/16
;	|            100  timer    IP2
;	|            101  timer    IP2/16
;	|            110  timer    X1 clock
;	|            111  timer    X1 clock/16
;	|            
;	|
;	+> 0: select BRG set #1
;	             1: select BRG set #2
;
dr_imr   =5                    ;interrupt enable mask (W)...
;
;	xxxxxxxx
;	||||||||
;	|||||||+> 1: ch A TxD ready
;	||||||+> 1: ch A RxD ready/FIFO full
;	|||||+> 1: ch A change in break
;	||||+> 1: C/T ready or underflow
;	|||+> 1: ch B TxD ready
;	||+> 1: ch B RxD ready/FIFO full
;	|+> 1: ch B change in break
;	+> 1: IP0-IP3 state change
;
dr_isr   =dr_imr               ;interrupt status (R)...
;
;	xxxxxxxx
;	||||||||
;	|||||||+> 1: ch A TxD ready
;	||||||+> 1: ch A RxD ready/FIFO full
;	|||||+> 1: ch A change in break
;	||||+> 1: C/T ready or underflowed
;	|||+> 1: ch B TxD ready
;	||+> 1: ch B RxD ready/FIFO full
;	|+> 1: ch B change in break
;	+> 1: IP0-IP3 state change
;
dr_crur  =6                    ;C/T MSB preset (W)
dr_crlr  =7                    ;C/T LSB preset (W)
dr_ctu   =6                    ;C/T MSB value (R)
dr_ctl   =7                    ;C/T LSB value (R)
dr_opcr  =13                   ;output port configuration (W)
dr_ipsr  =13                   ;input port status (R)
dr_sctc  =14                   ;start C/T command (R)
dr_sopbc =14                   ;set output port bits command (W)
dr_rctc  =15                   ;stop C/T command (R)
dr_ropbc =15                   ;reset output port bits command (W)
;
;
;	
;	Miscellaneous Register Definitions
;	
;
dr_usrdf =12                   ;user-defined temp storage (R/W)
;
	.end
