;================================================================================
;
;NXP 26C92 CONFIGURATION & CONTROL CONSTANTS
;
;	
;	The following constants are used to configure the 26C92 following reset
;	or during run time.  See the file NXP26C92_CONFIG.ASM for the use of
;	these constants.  The file CONFIG_LOOP.ASM contains the code that reads
;	the table in NXP26C92_CONFIG.ASM & loads the 26C92's registers.
;
;	    !!! WARNING !!! WARNING !!! WARNING !!! WARNING !!! WARNING !!!
;
;	Changing some of these constants may cause a complete loss of operation.
;	Be sure to read the data sheet so you understand exactly what each cons-
;	tant does to the 26C92.  Also note that these constants are not applic-
;	able to the 2692, which device lacks TxD FIFOs & extended baud rate mode
;	two.
;
;	Consecutive accesses to a command register must be separated by a mini-
;	mum of 3 X1 clock periods, approximately equal to 0.82 microseconds at
;	the recommended 3.6864 MHz X1 frequency.  Failure to heed this require-
;	ment will cause difficult-to-locate problems.
;	
;
;
;	ACR  auxiliary control register
;
u92arbrt =@01100000            ;BRT 1, C/T is timer, C/T clock = X1  1
;
;
;	CR  command register...
;
u92crrxe =@00000001            ;enable receiver
u92crrxd =@00000010            ;disable receiver
u92crtxe =@00000100            ;enable transmitter
u92crtxd =@00001000            ;disable transmitter
u92crmr1 =@00010000            ;select MR1
u92crrxr =@00100000            ;reset receiver
u92crtxr =@00110000            ;reset transmitter
u92cresr =@01000000            ;reset error status
u92crbir =@01010000            ;reset received break change IRQ
u92crbks =@01100000            ;start break
u92crbke =@01110000            ;stop break
u92crrsa =@10000000            ;assert request to send
u92crrsd =@10010000            ;deassert request to send
u92crtme =@10100000            ;enable counter/timer timeout mode
u92crmr0 =@10110000            ;select MR0
u92crtmd =@11000000            ;disable counter/timer timeout mode
u92crpde =@11100000            ;enable power-down mode  CRA only
u92crpdd =@11110000            ;disable power-down mode  CRA only
;
u92crrte =u92crtxe | u92crrxe  ;enable transmitter & receiver
u92crrtd =u92crtxd | u92crrxd  ;disable transmitter & receiver
;
;
;	CSR  clock select register...
;
u92csbra =@01100110            ;ch A: 115.2 Kbps
u92csbrb =@01100110            ;ch B: 115.2 Kbps
;
;
;	CT  counter/timer..
;
u92ctpre = 18432               ;100 counts per second...
;
;	
;	If you want to use the C/T as a jiffy IRQ generator you will need to add
;	some code to the ISR.  I have tested code that can use the C/T to main-
;	tain a 32 bit counter, with a resolution of 1 second.  The count rate is
;	sufficiently stable to be used as a timekeeping source.
;
;	Some additional code can also drive a 16 bit down-counter that can be
;	used to generate programmed time delays.  I do not use the C/T for tim-
;	ing purposes in POC V1 because the Dallas real-time clock can generate
;	the 100 Hz IRQ, as well as provide date & time-of-day outputs.
;	
;
;
;	MR0  mode 0 register...
;
u92m0ads =@10000100            ;ch A ext baud rate mode 2
u92m0bds =@10000000            ;defaults (MR0B only)
;
;
;	MR1  mode 1 register...
;
u92m1def =@10010011            ;8N1 format, auto CTS
;
;
;	MR2  mode 2 register...
;
u92m2def =@00010111            ;normal mode, auto RTS
;
;
;	OPCR  output port configuration register...
;
u92opdef =@00000000            ;no operation
;
	.end
