;================================================================================
;
;iirq: HARDWARE INTERRUPT REQUEST SERVICE ROUTINE
;
;	
;	This interrupt service routine (ISR) processes 26C92 interrupts & assum-
;	es that the 65C816 is in native mode.  Code unrelated to 26C92 IRQs may
;	be added at IIRQB below.  More commentary on this follows.
;
;	Your 65C816 IRQ vector at $00FFEE-$00FFEF should be set to the address
;	of this ISR, which is defined by IIRQ (below).
;	
;
iirq     phb                   ;save DB
         phd                   ;save DP
         longr                 ;16 bit registers
         pha                   ;save .C
         phx                   ;save .X
         phy                   ;save .Y
;
;
;Local Stack Frame Definitions
;
irq_yrx  .= 1                  ;.Y
irq_xrx  .= irq_yrx+s_word     ;.X
irq_arx  .= irq_xrx+s_word     ;.C
irq_dpx  .= irq_arx+s_word     ;DP
irq_dbx  .= irq_dpx+s_mpudpx   ;DB
irq_srx  .= irq_dbx+s_mpudbx   ;SR
irq_pcx  .= irq_srx+s_mpusrx   ;PC
irq_pbx  .= irq_pcx+s_mpupcx   ;PB
;
;
;         jmp (ivirq)           ;IRQ indirect vector...
;
;	
;	If your system has an indirect vector for IRQ processing (recommended),
;	it should point to the IIRQA label immediately below.  Also, be sure to
;	uncomment the above instruction.  Use of the indirect vector allows you
;	to patch code into your ISR for development & testing purposes.
;	
;
iirqa    ;continuation of ISR...
;
;	
;	If your ISR uses the indirect vector (IVIRQ) it would normally continue
;	execution here.  If uncommented, the next instructions would change the
;	execution environment to use an operating system kernel's direct page &
;	data bank.  There is corresponding code in the foreground functions for
;	this purpose.
;	
;
;         longa                 ;ensure 16 bit accumulator
;         ldaw kerneldp         ;set default...
;         tcd                   ;kernel DP
;
         shortr                ;8 bit registers
;         
;         lda #kerneldb         ;set...
;         pha                   ;default...
;         plb                   ;kernel DB
;
         lda io_acia+dr_isr    ;UART interrupt status register
         bne .iirq010          ;UART interrupting
;
         jmp iirqb             ;UART not interrupting...
;
;	
;	Add other interrupt processing starting at IIRQB.  Processing UART IRQs
;	should occur before other IRQ processing to avoid receiver overruns &
;	data loss.
;	
;
.iirq010 .rept s_e32iws        ;define fugacious workspace
           pea 0
         .endr
;
;
;Stack Workspace
;
.buffer  =1                    ;buffer base address
.channel =.buffer+s_ptr        ;channel base address
;
;
;
;	process RxD interrupts...
;
         ldx #n_schans-1       ;channel index
;
.iirq100 lda io_acia+dr_isr    ;get IRQ status mask
         bit d92rqtab,x        ;RxD interrupting?
         beq .iirq130          ;no
;
         txa                   ;make a...
         asl                   ;table offset...
         tay                   ;from channel index
         longa
         lda d92chtab,y        ;get & set...
         stas .channel         ;channel base address
         lda e32rbtab,y        ;get & set...
         stas .buffer          ;buffer base address
         shorta
;
.iirq110 ldy #c92_rhr          ;RxD FIFO offset
         ldasi .channel        ;read datum &...
         xba                   ;hold it
         lda e32putrx,x        ;buffer "put" index
         tay                   ;save current position
         ina                   ;next buffer position
         and #e32xmask         ;wrap to buffer boundary
         cmp e32getrx,x        ;buffer "get" index
         beq .iirq120          ;buffer full, drop datum
;
         xba                   ;swap datum w/index &...
         stasi .buffer         ;buffer it
         xba                   ;recover & set...
         sta e32putrx,x        ;new "put" index
;
.iirq120 ldy #c92_sr           ;status register offset
         ldasi .channel        ;get channel status
         bit #u92rxdr          ;more data in FIFO?
         bne .iirq110          ;yes, loop
;
.iirq130 dex
         bpl .iirq100          ;next channel
;
;
;	process TxD interrupt...
;
         ldx #n_schans-1       ;channel index
;
.iirq200 lda io_acia+dr_isr    ;get IRQ status mask
         bit d92tqtab,x        ;TxD interrupting?
         beq .iirq230          ;no, skip this channel
;
         txa                   ;make a...
         asl                   ;table offset...
         tay                   ;from channel index
         longa
         lda d92chtab,y        ;get & set...
         stas .channel         ;channel base address
         lda e32tbtab,y        ;get & set...
         stas .buffer          ;buffer base address
         shorta
         lda e32gettx,x        ;buffer "get" index
;
.iirq210 cmp e32puttx,x        ;buffer "put" index
         beq .iirq220          ;no data, shut down channel
;
         xba                   ;hold 'get' index
         ldy #c92_sr           ;status register offset
         ldasi .channel        ;get channel status
         bit #u92txdr          ;FIFO full?
         beq .iirq230          ;yes, defer transmission
;
         xba                   ;"get" index
         tay                   ;use as buffer offset &...
         xba                   ;also protect for later
         ldasi .buffer         ;get datum from buffer
         ldy #c92_thr          ;TxD FIFO offset
         stasi .channel        ;write datum to FIFO
         xba                   ;current buffer position
         ina                   ;new buffer position
         and #e32xmask         ;wrap to buffer boundary &...
         sta e32gettx,x        ;set new "get" index
         bra .iirq210          ;send another datum
;
.iirq220 lda #u92crtxd         ;disable...
         ldy #c92_cr           ;transmitter so it...
         stasi .channel        ;stops interrupting
         lda d92tstab,x        ;tell foreground that...
         tsb e32txst           ;transmitter is disabled
;
.iirq230 dex                   ;next channel
         bpl .iirq200          ;restart loop
;
         longa
         .rept s_e32iws        ;clean up stack
           pla
         .endr
         shorta
;
;--------------------------------------
;
iirqb    ;ISR continues here
;
;================================================================================
;
;crti: COMMON INTERRUPT RETURN
;
crti     longr                 ;16 bit registers
         ply                   ;restore Y
         plx                   ;restore X
         pla                   ;restore .C
         pld                   ;restore DP
         plb                   ;restore DB
         rti                   ;resume foreground processing
;
	.end
