;================================================================================
;
;NXP 26C92 INTERRUPT STATUS ANALYSIS MASKS
;
;	
;	These masks are used to set possible interrupt sources &  to analyze the
;	device's interrupt status.   All Philips/NXP multichannel UARTs are log-
;	ically organized as "blocks," with 2 UARTs in each block.  Note that the
;	A & B references in these definitions refer to the UARTs in each block &
;	are only coincidentally the same as the A & B communications channels.
;
;	There is one counter/timer (C/T) per block, hence only one C/T interrupt
;	mask.  The C/T IRQ should not be enabled unless your ISR is prepared to
;	service such activity.
;	
;
u92atirq =@00000001            ;ch A TxD
u92arirq =@00000010            ;ch A RxD
u92abirq =@00000100            ;ch A break change
u92ctirq =@00001000            ;C/T underflow
u92btirq =@00010000            ;ch B TxD
u92brirq =@00100000            ;ch B RxD
u92bbirq =@01000000            ;ch B break change
u92ipirq =@10000000            ;input port change
;
u92iqmsk =u92atirq|u92arirq|u92btirq|u92brirq ;|u92ctirq
;
;	
;	The above mask enables the TxD & RxD IRQs in both channels.  If you want
;	to use the C/T to generate jiffy IRQs uncomment its mask.
;	
;
;================================================================================
;
;NXP 26C92 CHANNEL STATUS ANALYSIS MASKS
;
u92rxdr  =@00000001            ;RxD: FIFO not empty
u92rxdf  =@00000010            ;RxD: FIFO full
u92txdr  =@00000100            ;TxD: FIFO not full
u92txdur =@00001000            ;TxD: FIFO empty
u92rxdor =@00010000            ;RxD: FIFO overrun
u92parer =@00100000            ;RxD: parity error
u92frmer =@01000000            ;RxD: framing error
u92break =@10000000            ;RxD: break
;
;=================================================================================
;
;26C92 MISCELLANEOUS MASKS
;
e32txsta =@00000001            ;ch A TxD status flag
e32txstb =@00000010            ;ch B TxD status flag
e32txstc =@00000100            ;ch C TxD status flag
e32txstd =@00001000            ;ch D TxD status flag
e32txste =@00010000            ;ch E TxD status flag
e32txstf =@00100000            ;ch F TxD status flag
e32txstg =@01000000            ;ch G TxD status flag
e32txsth =@10000000            ;ch H TxD status flag
;
e32xmask =s_e32buf ^ @11111111 ;buffer index wrap mask...
;
;	
;	This mask determines when to wrap I/O buffer indices back to zero.  Its
;	value must be commensurate with the actual buffer size defined by the
;	S_E32BUF constant.  It's probably best to let the assembler calculate
;	its value.  See comments in the file BUFFERS.ASM for more information.
;	
;
	.end
